==> panther-1.0.4.tar.gz: panther/tests/src/FunctionalJavascript/PantherTestCase.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\panther\FunctionalJavascript;

use Drupal\Driver\DrupalDriver;
use Drupal\panther\Drupal\Manager\DrupalUserManager;
use Drupal\panther\Drupal\Manager\EntityManager;
use Drupal\panther\Settings;
use Facebook\WebDriver\Remote\DesiredCapabilities;
use PHPUnit\Framework\TestCase;
use PHPUnit\Runner\BaseTestRunner;
use Symfony\Component\Panther\Client;

class PantherTestCase extends TestCase {

  use DomCrawlerAssertionsTrait;
  use DrupalAssertionsTrait;
  use DrupalTrait;
  use AccessibilityTrait;

  protected DrupalDriver $driver;
  protected EntityManager $entityManager;
  protected Settings $settings;

  protected function setUp(): void {
    parent::setUp();

    $drupal_root = \getenv('PANTHER_DRUPAL_ROOT');
    $drupal_host = \getenv('PANTHER_DRUPAL_HOST');

    if ($drupal_root === FALSE || $drupal_host === FALSE) {
      throw new \RuntimeException('PANTHER_DRUPAL_ROOT and PANTHER_DRUPAL_HOST environment variables must be set.');
    }

    $this->driver = new DrupalDriver($drupal_root, $drupal_host);
    $this->driver->setCoreFromVersion();

    // Bootstrap Drupal.
    $this->driver->bootstrap();

    /** @var \Drupal\Core\Database\Transaction\TransactionManagerBase $transaction_manager */
    $transaction_manager = \Drupal::database()->transactionManager();

    /** @var \Drupal\user\UserStorage $user_storage */
    $user_storage = \Drupal::entityTypeManager()->getStorage('user');

    $this->entityManager = new EntityManager(
      driver: $this->driver,
      userManager: new DrupalUserManager(),
      transactionManager: $transaction_manager,
      userStorage: $user_storage,
    );

    $this->settings = new Settings();
  }

  protected function tearDown(): void {
    parent::tearDown();

    $this->takeScreenshotIfTestFailed();

    // Build a new client instance for each test.
    self::getClient()->quit();
    self::resetClient();

    // Clean up.
    $this->entityManager->cleanAll();

    // Restore the error handler to avoid issues with PHPUnit.
    \restore_error_handler();
  }

  protected static function getClient(bool $reset = FALSE): Client {
    static $client;

    $selenium_host = \getenv('PANTHER_SELENIUM_HOST');
    $drupal_host = \getenv('PANTHER_DRUPAL_HOST');

    if ($selenium_host === FALSE || $drupal_host === FALSE) {
      throw new \RuntimeException('PANTHER_SELENIUM_HOST and PANTHER_DRUPAL_HOST environment variables must be set.');
    }

    if (!$client || $reset) {
      // '--disable-dev-shm-usage' is required to avoid the "session deleted
      // because of page crash" error.
      $capabilities = new DesiredCapabilities(
        [
          'browserName' => 'chrome',
          'goog:chromeOptions' => [
            'args' => [
              '--no-sandbox',
              '--disable-dev-shm-usage',
              '--disable-gpu',
            ],
          ],
        ],
      );

      $client = Client::createSeleniumClient(
        $selenium_host,
        $capabilities,
        $drupal_host,
        [
          'connection_timeout_in_ms' => 5000,
          'request_timeout_in_ms' => 5000,
        ],
      );
    }

    return $client;
  }

  private static function resetClient(): void {
    self::getClient(TRUE);
  }

  public function takeScreenshotIfTestFailed(): void {
    if (\class_exists(BaseTestRunner::class) && \method_exists(
        $this,
        'getStatus',
      )) {

      // PHPUnit <10 TestCase.
      $status = $this->getStatus();
      $isError = BaseTestRunner::STATUS_FAILURE === $status;
      $isFailure = BaseTestRunner::STATUS_ERROR === $status;
    }
    // @phpstan-ignore-next-line
    elseif (\method_exists($this, 'status')) {
      // PHPUnit 10 TestCase.
      $status = $this->status();
      $isError = $status->isError();
      $isFailure = $status->isFailure();
    }
    else {
      // Symfony WebTestCase.
      return;
    }
    if ($isError || $isFailure) {
      $type = $isError ? 'error' : 'failure';
      $this->takeScreenshot($type, $this->toString());
    }
  }

  public function takeScreenshot(string $type, string $test): void {
    $screenshot_dir = $this->settings->screenshotsDir;

    // Ensure the directory exists.
    if (!\is_dir($screenshot_dir)) {
      return;
    }

    // Ensure the directory is writable.
    if (!\is_writable($screenshot_dir)) {
      return;
    }

    $screenshot_path = \sprintf(
      '%s/%s_%s_%s.png',
      $screenshot_dir,
      \date('Y-m-d_H-i-s'),
      $type,
      \strtr($test, ['\\' => '-', ':' => '_']),
    );
    self::getClient()->takeScreenshot($screenshot_path);
  }

  protected function goToPage(string $path): void {
    self::getClient()->request('GET', $path);
  }

  protected function maximizeWindow(): void {
    self::getClient()->manage()->window()->maximize();
  }

  /**
   * @phpstan-param string[] $fields
   */
  protected function submitForm(string $button, array $fields): void {
    self::getClient()->submitForm($button, $fields);
  }

  protected function clickLink(string $string): void {
    self::getClient()->clickLink($string);
  }

  protected function clickButton(string $string): void {
    self::getClient()->getCrawler()->selectButton($string)->click();
  }

}

==> panther-1.0.7.tar.gz: panther/tests/src/FunctionalJavascript/PantherTestCase.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\panther\FunctionalJavascript;

use Drupal\Driver\DrupalDriver;
use Drupal\panther\Drupal\Manager\DrupalUserManager;
use Drupal\panther\Drupal\Manager\EntityManager;
use Drupal\panther\Settings;
use Facebook\WebDriver\Exception\Internal\IOException;
use PHPUnit\Framework\TestCase;

class PantherTestCase extends TestCase {

  use AccessibilityTrait;
  use DomCrawlerAssertionsTrait;
  use DrupalAssertionsTrait;
  use DrupalTrait;
  use PantherTrait;

  protected DrupalDriver $driver;

  protected EntityManager $entityManager;

  protected Settings $settings;

  protected function setUp(): void {
    parent::setUp();

    $drupal_root = \getenv('PANTHER_DRUPAL_ROOT');
    $drupal_host = \getenv('PANTHER_DRUPAL_HOST');

    if ($drupal_root === FALSE || $drupal_host === FALSE) {
      throw new \RuntimeException(
        'PANTHER_DRUPAL_ROOT and PANTHER_DRUPAL_HOST environment variables must be set.',
      );
    }

    $this->driver = new DrupalDriver($drupal_root, $drupal_host);
    $this->driver->setCoreFromVersion();

    // Bootstrap Drupal.
    $this->driver->bootstrap();

    /** @var \Drupal\Core\Database\Transaction\TransactionManagerBase $transaction_manager */
    $transaction_manager = \Drupal::database()->transactionManager();

    /** @var \Drupal\user\UserStorage $user_storage */
    $user_storage = \Drupal::entityTypeManager()->getStorage('user');

    $this->entityManager = new EntityManager(
      driver: $this->driver,
      userManager: new DrupalUserManager(),
      transactionManager: $transaction_manager,
      userStorage: $user_storage,
    );

    $this->settings = new Settings();

    $this->createDirectoryIfNotExists($this->settings->accessibilityReportsDir);
    $this->createDirectoryIfNotExists($this->settings->screenshotsDir);
  }

  protected function tearDown(): void {
    parent::tearDown();

    $this->takeScreenshotIfTestFailed();

    // Build a new client instance for each test.
    self::getClient()->quit();
    self::resetClient();

    // Clean up.
    $this->entityManager->cleanAll();

    // Restore the error handler to avoid issues with PHPUnit.
    \restore_error_handler();
  }

  private function createDirectoryIfNotExists(string $directory_path): void {
    if (!\file_exists($directory_path)) {
      if (!\mkdir($directory_path, 0777, TRUE) && !\is_dir($directory_path)) {
        throw IOException::forFileError(
          'Directory cannot be not created',
          $directory_path,
        );
      }
    }
  }

}
